[SCM] ktp-accounts-kcm packaging branch, master, updated. debian/15.12.1-1-1157-gc4589c5

Maximiliano Curia maxy at moszumanska.debian.org
Fri May 27 23:59:06 UTC 2016


Gitweb-URL: http://git.debian.org/?p=pkg-kde/applications/ktp-accounts-kcm.git;a=commitdiff;h=e95b2d8

The following commit has been merged in the master branch:
commit e95b2d811fb5feab83b8048e706635f349026b45
Author: Lasath Fernando <kde at lasath.org>
Date:   Sat Feb 12 13:31:00 2011 +1100

    more minor changes
---
 haze/CMakeLists.txt                | 8 +++++---
 haze/haze-account-ui-plugin.cpp    | 9 +++++++--
 haze/haze-icq-account.cpp          | 4 ++--
 haze/haze-icq-account.h            | 4 ++--
 haze/haze-yahoo-account.h          | 4 ++--
 haze/yahoo-main-options-widget.cpp | 8 ++------
 6 files changed, 20 insertions(+), 17 deletions(-)

diff --git a/haze/CMakeLists.txt b/haze/CMakeLists.txt
index da6e2ba..4fe6ff4 100644
--- a/haze/CMakeLists.txt
+++ b/haze/CMakeLists.txt
@@ -6,14 +6,17 @@ include_directories (${CMAKE_CURRENT_BINARY_DIR}
 
 set (kcmtelepathyaccounts_plugin_haze_SRCS
      haze-account-ui-plugin.cpp
-     haze-icq-account-ui.cpp
+     haze-icq-account.cpp
      icq-main-options-widget.cpp
      icq-server-settings-widget.cpp
+     haze-yahoo-account.cpp
+     yahoo-main-options-widget.cpp
 )
 
 kde4_add_ui_files (kcmtelepathyaccounts_plugin_haze_SRCS
                    icq-main-options-widget.ui
                    icq-server-settings-widget.ui
+		   yahoo-main-options-widget.ui
 )
 
 kde4_add_plugin (kcmtelepathyaccounts_plugin_haze
@@ -34,5 +37,4 @@ install (TARGETS kcmtelepathyaccounts_plugin_haze
 
 install (FILES kcmtelepathyaccounts_plugin_haze.desktop
          DESTINATION ${SERVICES_INSTALL_DIR}
-)
-
+)
\ No newline at end of file
diff --git a/haze/haze-icq-account.cpp b/haze/haze-icq-account.cpp
index 98f3ce3..2284388 100644
--- a/haze/haze-icq-account.cpp
+++ b/haze/haze-icq-account.cpp
@@ -27,7 +27,7 @@
 #include "icq-main-options-widget.h"
 #include "icq-server-settings-widget.h"
 
-#include "haze-icq-account-ui.h"
+#include "haze-icq-account.h"
 
 
 
@@ -93,5 +93,5 @@ AbstractAccountParametersWidget *HazeIcqAccountUi::advancedOptionsWidget(
 }
 
 
-#include "haze-icq-account-ui.moc"
+#include "haze-icq-account.moc"
 
diff --git a/haze/haze-icq-account.h b/haze/haze-icq-account.h
index bff28a4..d90c789 100644
--- a/haze/haze-icq-account.h
+++ b/haze/haze-icq-account.h
@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_ICQ_ACCOUNT_UI_H
-#define KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_ICQ_ACCOUNT_UI_H
+#ifndef KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_ICQ_ACCOUNT_H
+#define KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_ICQ_ACCOUNT_H
 
 #include <KCMTelepathyAccounts/AbstractAccountUi>
 
diff --git a/haze/haze-yahoo-account.h b/haze/haze-yahoo-account.h
index 3d1299c..1f94f44 100644
--- a/haze/haze-yahoo-account.h
+++ b/haze/haze-yahoo-account.h
@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_YAHOO_ACCOUNT_UI_H
-#define KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_YAHOO_ACCOUNT_UI_H
+#ifndef KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_YAHOO_ACCOUNT_H
+#define KCMTELEPATHYACCOUNTS_PLUGIN_HAZE_YAHOO_ACCOUNT_H
 
 #include <KCMTelepathyAccounts/AbstractAccountUi>
 
diff --git a/haze/yahoo-main-options-widget.cpp b/haze/yahoo-main-options-widget.cpp
index 179eaba..637697e 100644
--- a/haze/yahoo-main-options-widget.cpp
+++ b/haze/yahoo-main-options-widget.cpp
@@ -28,15 +28,10 @@ public:
   Ui::YahooMainOptionsWidget* ui;
   
     Private()
-      : ui(NULL)
+      : ui(0)
     {
         kDebug();
     }
-    
-    ~Private()
-    {
-      delete ui;
-    }
 };
 
 YahooMainOptionsWidget::YahooMainOptionsWidget(ParameterEditModel* model, QWidget* parent)
@@ -57,5 +52,6 @@ YahooMainOptionsWidget::~YahooMainOptionsWidget()
 {
   kDebug();
   
+  delete d->ui;
   delete d;
 }

diff --git a/haze/haze-account-ui-plugin.cpp b/haze/haze-account-ui-plugin.cpp
index e684150..2e5a386 100644
--- a/haze/haze-account-ui-plugin.cpp
+++ b/haze/haze-account-ui-plugin.cpp
@@ -20,7 +20,8 @@
 
 #include "haze-account-ui-plugin.h"
 
-#include "haze-icq-account-ui.h"
+#include "haze-icq-account.h"
+#include "haze-yahoo-account.h"
 
 #include <KCMTelepathyAccounts/PluginMacros>
 
@@ -46,6 +47,7 @@ HazeAccountUiPlugin::HazeAccountUiPlugin(QObject *parent, const QVariantList &)
 
     // Register supported cm/protocol combinations
     registerProvidedProtocol("haze", "icq");
+    registerProvidedProtocol("haze", "yahoo");
 }
 
 HazeAccountUiPlugin::~HazeAccountUiPlugin()
@@ -59,10 +61,13 @@ AbstractAccountUi* HazeAccountUiPlugin::accountUi(const QString &connectionManag
 
     kDebug();
 
     // We only support haze/icq combination.so far
     if ((connectionManager == "haze") && (protocol == "icq")) {
         return new HazeIcqAccountUi;
     }
+    if ((connectionManager == "haze") && (protocol == "yahoo")){
+      return new HazeYahooAccount;
+    }
 
     return 0;
 }
@@ -59,10 +61,13 @@ AbstractAccountUi* HazeAccountUiPlugin::accountUi(const QString &connectionManag
     kDebug();
 
-    // We only support haze/icq combination.so far
+    // We only support haze/icq and yahoo combination so far
     if ((connectionManager == "haze") && (protocol == "icq")) {
         return new HazeIcqAccountUi;
-- 
ktp-accounts-kcm packaging



More information about the pkg-kde-commits mailing list